@@ -5,41 +5,44 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 $VERSION =~ tr/_//d;
 
-use Carp qw(verbose);    # makes carp() cluck and croak() confess
-
-sub _warn {
-  if ($_[-1] =~ /\n$/s) {
-    my $arg = pop @_;
-    $arg =~ s/(.*)( at .*? line .*?\n$)/$1/s;
-    push @_, $arg;
-  }
-  warn &Carp::longmess;
+BEGIN {
+  require Carp;
+  $Carp::CarpInternal{ +__PACKAGE__ }++;
 }
 
-sub _die {
-  die @_ if ref($_[0]);
-  if ($_[-1] =~ /\n$/s) {
+sub _warn { warn &_longmess }
+
+sub _die { die ref $_[0] ? @_ : &_longmess }
+
+sub _longmess {
+  if ($_[-1] =~ /\n\z/) {
     my $arg = pop @_;
-    $arg =~ s/(.*)( at .*? line .*?\n$)/$1/s;
+    $arg =~ s/(.*) at [^\n]*? line [0-9]+\.?\n$/$1/s;
     push @_, $arg;
   }
-  die &Carp::longmess;
+  &Carp::longmess;
 }
 
+my @HOOKS = qw(__DIE__ __WARN__);
 my %OLD_SIG;
 
-BEGIN {
-  @OLD_SIG{qw(__DIE__ __WARN__)} = @SIG{qw(__DIE__ __WARN__)};
+sub import {
+  my $class = shift;
+  return if $OLD_SIG{$class};
+  @{ $OLD_SIG{$class} }{@HOOKS} = @SIG{@HOOKS};
 
-  $SIG{__DIE__}  = \&_die;
-  $SIG{__WARN__} = \&_warn;
+  @SIG{@HOOKS} = ($class->can('_die'), $class->can('_warn'));
+  $Carp::Verbose = 'verbose';    # makes carp() cluck and croak() confess
 }
 
-END {
-  @SIG{qw(__DIE__ __WARN__)} = @OLD_SIG{qw(__DIE__ __WARN__)};
+sub unimport {
+  my $class = shift;
+  return unless $OLD_SIG{$class};
+  @SIG{@HOOKS} = @{ delete $OLD_SIG{$class} }{@HOOKS};
+  undef $Carp::Verbose;
 }
 
 1;
@@ -83,15 +86,36 @@ looks:
 In the implementation, the L<Carp> module does
 the heavy work, through C<longmess()>. The
 actual implementation sets the signal hooks
-C<$SIG{__WARN__}> and C<$SIG{__DIE__}> to
+L<$SIG{__WARN__}|perlvar/%SIG> and L<$SIG{__DIE__}|perlvar/%SIG> to
 emit the stack backtraces.
 
 Also, all uses of C<carp> and C<croak> are made verbose,
 behaving like C<cluck> and C<confess>.
 
-=head2 EXPORT
+=head1 METHODS
 
-Nothing at all is exported.
+L<Carp::Always> implements the following methods.
+
+=head2 import
+
+  Carp::Always->import()
+
+Enables L<Carp::Always>. Also triggered by statements like
+
+  use Carp::Always;
+  use Carp::Always 0.14;
+
+but not by
+
+  use Carp::Always ();    # does not invoke import()
+
+=head2 unimport
+
+  Carp::Always->unimport();
+
+Disables L<Carp::Always>. Also triggered with
+
+  no Carp::Always;
 
 =head1 ACKNOWLEDGMENTS
 
@@ -119,6 +143,8 @@ L<Carp::Source::Always>
 
 L<Devel::Confess>
 
+L<Carp::Always::SyntaxHighlightSource> and L<Carp::Always::DieOnly>
+
 =head1 BUGS
 
 =over 4
@@ -126,8 +152,7 @@ L<Devel::Confess>
 =item *
 
 This module does not play well with other modules which fusses
-around with C<warn>, C<die>, C<$SIG{__WARN__}>,
-C<$SIG{__DIE__}>.
+around with C<warn>, C<die>, C<$SIG{__WARN__}>, C<$SIG{__DIE__}>.
 
 =item *
 
